const system = require("../../../system");
var settings = require("../../../../config/settings");
var APIBase = require("../../api.base");

class TradetransferAPI extends APIBase {
  constructor() {
    super();
    this.execlient = system.getObject("util.execClient");
    this.utilsNeedSve = system.getObject("service.utilsSve.utilsNeedSve");
    this.channelApiUrl = settings.channelApiUrl();
    this.centerChannelUrl = settings.centerChannelUrl();
    this.appInfo = {
      aliyuntmtransfer: { appkey: settings.appKey, secret: settings.secret }
    };
  }

  async getToken() {
    var self = this;
    var reqTokenUrl = this.channelApiUrl + "/auth/accessAuth/getToken";
    var reqParam = self.appInfo["aliyuntmtransfer"];
    if (!reqParam.appkey || !reqParam.secret) {
      return system.getResult(null, "reqType类型有误，请求失败");
    }
    var rtn = await this.execlient.execPost(reqParam, reqTokenUrl);
    if (!rtn.stdout) {
      return system.getResult(null, "获取token失败");
    }
    var tokenResult = JSON.parse(rtn.stdout);
    if (tokenResult.status == 0) {
      tokenResult.data.secret = reqParam.secret;
    }
    return tokenResult;
  }

  //订单创建
  // 2020 0828 lin 修改 匹配商标交易
  async acceptOrder(pobj,qobj,req) {
    if (!pobj.BizId) {
      return {
        "ErrorCode": "error",
        "ErrorMsg": "订单号不能为空",
        "Module": { "orderNumber": "" },
        "RequestId": req.requestId,
        "Success": false
      }
    }
    if (!pobj.UserName) {
      return {
        "ErrorCode": "error",
        "ErrorMsg": "用户不能为空",
        "Module": { "orderNumber": "" },
        "RequestId": req.requestId,
        "Success": false
      }
    }
    if (!pobj.Mobile) {
      return {
        "ErrorCode": "error",
        "ErrorMsg": "用户手机号不能为空",
        "Module": { "orderNumber": "" },
        "RequestId": req.requestId,
        "Success": false
      }
    }
    if (!pobj.Price) {
      return {
        "ErrorCode": "error",
        "ErrorMsg": "价格不能为空",
        "Module": { "orderNumber": "" },
        "RequestId": req.requestId,
        "Success": false
      }
    }
    if (!pobj.RegisterNumber) {
      return {
        "ErrorCode": "error",
        "ErrorMsg": "商标注册号不能为空",
        "Module": { "orderNumber": "" },
        "RequestId": req.requestId,
        "Success": false
      }
    }
    if (!pobj.Classification) {
      return {
        "ErrorCode": "error",
        "ErrorMsg": "商标国际一级分类不能为空",
        "Module": { "orderNumber": "" },
        "RequestId": req.requestId,
        "Success": false
      }
    }
    var sobj = {
      "actionProcess": "aliyuntmtransfer",
      "actionType": "aliclient",
      "actionBody": {
        "bizId": pobj.BizId,
        "userName": pobj.UserName,
        "mobile": pobj.Mobile,
        "registerNumber": pobj.RegisterNumber,
        "classification": pobj.Classification,
        "price": pobj.price
      }
    }
    // 获取token
    var tokenInfo = await this.getToken();
    if (tokenInfo.status != 0) {
      return {
        "ErrorCode": "error",
        "ErrorMsg": "网络错误",
        "Module": { "orderNumber": "" },
        "RequestId": req.requestId,
        "Success": false
      };
    }
    // 获取userpin
    var userparam = {
      actionType: "getLoginByUserName",
      actionBody: {
        "channelUserId": pobj.Mobile,
        "mobile": pobj.Mobile,
        "userName": pobj.Mobile
      }
    };
    var url = settings.centerChannelUrl() + "/api/opreceive/accessAuth/springBoard";
    var userpinResultTmp = await this.execlient.execPostTK(userparam, url, tokenInfo.data.token);
    if (userpinResultTmp.status != 0 && userpinResultTmp.status != 2060) {
      return {
        "ErrorCode": "error",
        "ErrorMsg": "网络错误",
        "Module": { "orderNumber": "" },
        "RequestId": req.requestId,
        "Success": false
      };
    }
    // 调取channel 开始业务
    var url = this.channelApiUrl + "/action/tradetransfer/createtransfer";
    // var rtn = await this.execlient.execPostTK(sobj, url, tokenInfo.data.token);
    var rtn = rtn = await this.execlient.execDataPostByTokenUserPin(sobj, url, tokenInfo.data.token, userpinResultTmp.data.userpin);
    return rtn;
  }
  //订单查询
  async queryOrderState(p,obj) {
    var sobj = {
      "actionProcess": "aliyuntmtransfer",
      "actionType": "aliclient",
      "sign": "2FviZ9PGws8Pt1fBhq0t90mjUvI",
      "actionBody": p
    }
    var tokenInfo = await this.getToken();
    console.log(tokenInfo);
    var url = this.channelApiUrl + "/action/tradetransfer/ordersel";
    var rtn = await this.execlient.execPostTK(sobj, url, tokenInfo.data.token);
    console.log(rtn);
    // var rtn = await this.execlient.execPostTK(sobj, url,"token");
    return rtn;
  }

  //订单关闭
  async closeOrder(p,obj) {
    var sobj = {
      "actionProcess": "aliyuntmtransfer",
      "actionType": "aliclient",
      "sign": "2FviZ9PGws8Pt1fBhq0t90mjUvI",
      "actionBody": p
    }
    var tokenInfo = await this.getToken();
    var url = this.channelApiUrl + "/action/tradetransfer/orderclose";
    var rtn = await this.execlient.execPostTK(sobj, url, tokenInfo.data.token);
    // var rtn = await this.execlient.execPostTK(sobj, url,"token");
    return rtn;
  }


  //查询咨询客户列表
  async queryTradeIntentionUserList(p,obj) {
    let sobj = {
      "actionType": "QueryTradeIntentionUserList",
    };
    let tokenInfo = await this.utilsNeedSve.getCenterToken();
    let url = this.centerChannelUrl + "/web/trade/brand/springBoard";
    return await this.execlient.execPostTK(sobj, url, tokenInfo.data.token);
  }

}
module.exports = TradetransferAPI;
